@@ -250,7 +250,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
             s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            url = self._base_url_askdata + '/agents/agentslug/'+self.slug+'/datasetslug/'+dataset_slug
+            url = self._base_url_askdata + '/smartbot/agents/agentslug/'+self.slug+'/datasetslug/'+dataset_slug
             logging.info("URL {}".format(url))
 
             headers = {"Authorization": "Bearer" + " " + self._token}
