@@ -25,8 +25,8 @@ class TimeDimensionGranularity(Enum):
 
 
 class SignOperator(Enum):
-    POS = auto()
-    NEG = auto()
+    NEXT = auto()
+    PREV = auto()
 
 
 @dataclass
